AutonML
=======

AutonML is an automated machine learning system developed by CMU's Auton Lab to power data scientists with efficient model discovery and advanced data analytics.

Documentation
-------------



Installation
------------

To install::
        pip install autonml
        pip install d3m-common-primitives d3m-sklearn-wrap sri-d3m rpi-d3m-primitives dsbox-primitives dsbox-corex distil-primitives d3m-esrnn d3m-nbeats 
        pip install kf-d3m-primitives

*Requies Python >= 3.6*

License
-------

AutonML is shared under the Apache license, available in the license file.